@@ -15,8 +15,11 @@ use constant {
 	# Lowest compat level that does *not* cause deprecation
 	# warnings
 	'LOWEST_NON_DEPRECATED_COMPAT_LEVEL' => 9,
+	# Lowest compat level to generate "debhelper-compat (= X)"
+	# relations for.
+	'LOWEST_VIRTUAL_DEBHELPER_COMPAT_LEVEL' => 9,
 	# Highest compat level permitted
-	'MAX_COMPAT_LEVEL' => 12,
+	'MAX_COMPAT_LEVEL' => 13,
 	# Magic value for xargs
 	'XARGS_INSERT_PARAMS_HERE' => \'<INSERT-HERE>', #'# Hi emacs.
 	# Magic value for debhelper tools to request "current version"
@@ -453,6 +456,7 @@ sub _doit {
 					chdir($dir) or error("chdir(\"${dir}\) failed: $!");
 				}
 			}
+			open(STDIN, '<', '/dev/null') or error("redirect STDIN failed: $!");
 			if (defined(my $output = $options->{stdout})) {
 				open(STDOUT, '>', $output) or error("redirect STDOUT failed: $!");
 			}
@@ -1383,9 +1387,17 @@ sub filedoublearray {
 	my @ret;
 	while (<DH_FARRAY_IN>) {
 		chomp;
-		if (not $x)  {
-			next if /^#/ || /^$/;
+		if ($x) {
+			if (m/^\s++$/) {
+				error("Executable config file $file produced a non-empty whitespace-only line");
+			}
+		} else {
+			s/^\s++//;
+			next if /^#/;
+			s/\s++$//;
 		}
+		# We always ignore/permit empty lines
+		next if $_ eq '';
 		my @line;
 
 		if (defined($globdir) && ! $x) {
